#
# spec file for package perl-experimental
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name experimental
Name:           perl-experimental
Version:        0.036
Release:        1.1
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Experimental features made easy
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/L/LE/LEONT/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::More) >= 0.89
BuildRequires:  perl(version)
Requires:       perl(version)
%{perl_requires}

%description
This pragma provides an easy and convenient way to enable or disable
experimental features.

Every version of perl has some number of features present but considered
"experimental." For much of the life of Perl 5, this was only a designation
found in the documentation. Starting in Perl v5.10.0, and more aggressively
in v5.18.0, experimental features were placed behind pragmata used to
enable the feature and disable associated warnings.

The 'experimental' pragma exists to combine the required incantations into
a single interface stable across releases of perl. For every experimental
feature, this should enable the feature and silence warnings for the
enclosing lexical scope:

  use experimental 'feature-name';

%prep
%autosetup -n %{cpan_name}-%{version} -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Thu Jul 17 2025 Tina Müller <timueller+perl@suse.de>
- updated to 0.036
  see /usr/share/doc/packages/perl-experimental/Changes
  0.036     2025-07-17 01:40:39+02:00 Europe/Brussels
  - Add features "class", "keyword_any" and "keyword_all"
* Fri May  2 2025 Tina Müller <timueller+perl@suse.de>
- updated to 0.035
  see /usr/share/doc/packages/perl-experimental/Changes
  0.035     2025-05-01 11:35:41+02:00 Europe/Berlin
  - regex_sets no longer experimental
  - switch/smartmatch were deprecated then undeprecated
  - Properly handle the win32_perlio warning
* Fri Jan 10 2025 Tina Müller <timueller+perl@suse.de>
- updated to 0.034
  see /usr/share/doc/packages/perl-experimental/Changes
  0.034     2025-01-09 22:11:31+01:00 Europe/Brussels
  - Rerelease to deal with illegal core update
* Tue Dec 24 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.033
  see /usr/share/doc/packages/perl-experimental/Changes
  0.033     2024-12-24 00:50:41+01:00 Europe/Brussels
  - feature extra_paired_delimiters not considered stable
* Fri Apr 26 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.032
  see /usr/share/doc/packages/perl-experimental/Changes
  0.032     2024-04-25 22:30:41+01:00 Europe/Lisbon
  - Add the newly-stable features to stable.pm - extra_paired_delimiters, const_attr, for_list
* Wed Feb  1 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.031
  see /usr/share/doc/packages/perl-experimental/Changes
  0.031     2023-01-31 22:46:02+01:00 Europe/Amsterdam
  - Fix the name of the extra_paired_delimiters feature (previously
    mis-documented as extra_paired_delims)
  - Added "stable.pm", which acts like experimental.pm only for
    features which have been marked non-experimental in their current
    form, in later version of perl.
* Sun Dec 11 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.030
  see /usr/share/doc/packages/perl-experimental/Changes
  0.030     2022-12-10 13:02:15+01:00 Europe/Amsterdam
  - Adapt to future deprecation of smartmatch
* Wed Oct 26 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.029
  see /usr/share/doc/packages/perl-experimental/Changes
  0.029     2022-10-25 23:22:21+02:00 Europe/Amsterdam
  - Fix handling of warning categories that have been removed
* Tue Apr 26 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.028
  see /usr/share/doc/packages/perl-experimental/Changes
  0.028     2022-04-26 02:02:45+02:00 Europe/Amsterdam
  - Add extra_paired_delims feature
* Wed Feb  9 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.027
  see /usr/share/doc/packages/perl-experimental/Changes
  0.027     2022-02-08 18:41:07+01:00 Europe/Amsterdam
  - Update documented list of experiments
  0.026     2022-02-08 14:41:02+01:00 Europe/Amsterdam
  - Added defer experiment
  - Added for_list experiment
  - Added builtin experiment
  - args_array_with_signatures
* Sat Jul 31 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.025
  see /usr/share/doc/packages/perl-experimental/Changes
  0.025     2021-07-30 14:41:39+02:00 Europe/Amsterdam
  - Add missing documentation for try
* Sun May  2 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.024
  see /usr/share/doc/packages/perl-experimental/Changes
  0.024     2021-05-01 19:44:14+02:00 Europe/Amsterdam
  - Rereleased without NYTProf files
  0.023     2021-04-30 19:35:09+02:00 Europe/Amsterdam
  - Added try feature
* Tue May  5 2020 Tina Müller <timueller+perl@suse.de>
  updated to 0.022
  see /usr/share/doc/packages/perl-experimental/Changes
  0.022     2020-05-04 22:34:48+02:00 Europe/Amsterdam
  - Skip tests when needed, to allow installation on <5.10
* Sun Feb 23 2020 <timueller+perl@suse.de>
- updated to 0.021
  see /usr/share/doc/packages/perl-experimental/Changes
  0.021     2020-02-22 23:18:22+01:00 Europe/Amsterdam
  - Add the isa feature
* Thu May 10 2018 coolo@suse.com
- updated to 0.020
  see /usr/share/doc/packages/perl-experimental/Changes
  0.020     2018-05-09 21:31:22+02:00 Europe/Amsterdam
  - Add the declared_refs feature
* Fri Dec  8 2017 coolo@suse.com
- updated to 0.019
  see /usr/share/doc/packages/perl-experimental/Changes
  0.019     2017-12-03 18:40:19+01:00 Europe/Amsterdam
  - Rerelease without NYTProf files
  0.018     2017-11-29 12:39:58+01:00 Europe/Amsterdam
  - Make test pass when warnings are enabled
  - Make experimental installable on 5.8
* Wed Nov 15 2017 coolo@suse.com
- updated to 0.017
  see /usr/share/doc/packages/perl-experimental/Changes
  0.017     2017-11-14 16:23:53+01:00 Europe/Amsterdam
    Remove auto_deref for 5.24+
* Sun Oct 11 2015 coolo@suse.com
- updated to 0.016
  see /usr/share/doc/packages/perl-experimental/Changes
  0.016     2015-10-10 12:46:48+02:00 Europe/Amsterdam
    Fix deprecation check
* Sun Oct  4 2015 coolo@suse.com
- updated to 0.015
  see /usr/share/doc/packages/perl-experimental/Changes
  0.015     2015-10-03 14:21:18+02:00 Europe/Amsterdam
    Make lexical_topic a deprecated feature
* Mon Sep 14 2015 coolo@suse.com
- updated to 0.014
  see /usr/share/doc/packages/perl-experimental/Changes
  0.014     2015-09-12 00:29:37+02:00 Europe/Amsterdam
    Add bitwise to list of known features
* Mon Oct 27 2014 ncutler@suse.com
- updated to 0.013
* Mon Oct 27 2014 ncutler@suse.com
  Upstream changes
- 0.013 Rename lvalue_refs to refaliasing
* Mon Oct 13 2014 ncutler@suse.com
  Upstream changes
- 0.012 Added lvalue references feature
* Mon Sep 29 2014 ncutler@suse.com
  Upstream changes
- 0.011 Clarified which order to apply pragmas [Grant McLean]
- 0.010 Add returning 1's to evals in tests
- 0.009 Hardcode features for perl < 5.15.7
* Thu Aug  7 2014 ncutler@suse.com
- initial package 0.008
  * created by cpanspec 1.78.08
- checked license
- took over maintainership
